package fr.faraphel.m1_pe_kafka.kafka

import org.apache.kafka.clients.admin.Admin
import org.apache.kafka.clients.admin.AdminClientConfig
import org.apache.kafka.clients.admin.CreateTopicsResult
import org.apache.kafka.clients.admin.NewTopic
import java.util.*


/**
 * A wrapper around KafkaAdminClient to simplify its configuration.
 * @param server the kafka server address
 * @param identifier the kafka identifier for the configuration
 * @see Admin
 */
class AdminUtils(
    private val server: String,
    private val identifier: String = "admin"
) {
    private val adminConfig = Properties().apply {
        // set the identifier
        this[AdminClientConfig.CLIENT_ID_CONFIG] = identifier
        // set the server information
        this[AdminClientConfig.BOOTSTRAP_SERVERS_CONFIG] = server
    }

    private val admin = Admin.create(adminConfig)

    /**
     * Create the topics in the kafka server.
     * @param topics the names of the topics to create.
     * @return the result of the operation.
     * @see Admin.createTopics
     */
    fun createTopics(vararg topics: String): CreateTopicsResult {
        // convert the topics name into the corresponding operation
        val operations = topics.map { topic -> NewTopic(topic, 1, 1) }
        // run the command
        return this.admin.createTopics(operations)
    }
}
